Class initializer for NlmeTableDef
NlmeTableDef-class.RdCreates NlmeTableDef class object used to specify parameters for fitting runs
Arguments
- name
Name of the generated simulation file.
- timesList
Numeric; Time values for simulation. Applicable for time-based models only. Ignored when
"keepSource=TRUE"- covrSet
Character; Vector of covariate names. Simulation point is added when the covariate value is set. See
covariateNames- whenDose
Character; Vector of dosing compartment names. Simulation point is added when the dose value is set.
- whenObs
Character; String of observed variables names. Simulation point is added when the observation value is set.
- variablesList
Character; List of variables from the model for simulation.
- keepSource
Logical; Set to
TRUEto keep the number of rows appearing in the table the same as the number of rows in the input dataset.- timeAfterDose
Set to
TRUEto output time after dose.- IRES
Logical; Set to
TRUEto output individual residuals. Valid only if whenObs is specified.- Weight
Logical; Set to
TRUEto output the weight of current observation. Valid only if whenObs is specified.- IWRES
Logical; Set to
TRUEto output individual weighted residuals. Valid only if whenObs is specified.- mode
Character; The mode of output. Options are
"all"(default),"unique","first". Only applicable to non time-based models for the case where onlycovrSetis defined or the case where onlycovrSetandvariablesListare defined.Option
"all"(default): it outputs all the rows invoked by specified covariates. Option"unique": if the values in a row are the same as the ones in the previous row for the current subject, then the row is omitted; otherwise, it is printed out. Option"first": it outputs only the first row for each subject.