Skip to contents

Updates PML statements in model object with estimates returned from model execution. Use copyModel and set argument acceptAllEffects = TRUE to create new model object with final estimates from base model run.

Usage

acceptAllEffects(model)

Arguments

model

Model object

Value

NlmePmlModel object

See also

Examples

if (FALSE) { # \dontrun{
# Define the model
model <- pkmodel(numComp = 1,
                 absorption = "Intravenous",
                 ID = "Subject",
                 Time = "Act_Time",
                 CObs = "Conc",
                 A1 = "Amount",
                 data = pkData,
                 modelName = "PkModel",
                 workingDir = tempdir())

# Fit model
res <- fitmodel(model = model,
                hostPlatform = hostParams(sharedDirectory = tempdir()))
model <- acceptAllEffects(model)
} # }