extract files used for powershell script
extract_mmdl.RdUse for extraction of the NLME files from mmdl file.
Usage
extract_mmdl(
mmdlfile,
directoryToExtract,
dataFileName = "data1.txt",
mdlOutput = "test.mdl",
cols1Output = "cols1.txt",
nlmeargsOutput = "nlmeargs.txt"
)Arguments
- mmdlfile
The metamodel file path; relative paths are acceptable.
- directoryToExtract
The directory where the files should be stored If
missing, current working directory is used.- dataFileName
the name of the data file If
missing, the default file name 'data1.txt' is used to preparenlmeargsOutputfile- mdlOutput
the name of the file to output PML code If
missing, the default file name 'test.mdl' is used.- cols1Output
the name of the file to output columns defintion If
missing, the default file name 'cols1.txt' is used.- nlmeargsOutput
the name of the file to output engine parameters If
missing, the default file name 'nlmeargs.txt' is used.
Value
The results of read_mmdl() run are returned.
Details
mdlOutput, dataFileName, cols1Output, nlmeargsOutput files are
extracted into the folders, the names of the folders are built as
{Number of estimation/simulation block in metamodel}-
{'est' for estimation block/'sim' for simulation block}. All estimation blocks are going first
irrespective of the simulation blocks presence, all simulation blocks
are going next.
Examples
if (FALSE) { # \dontrun{
# path to metamodel should be specified, all other arguments set to default
extract_mmdl(system.file("extdata/mmdlNoTime", "test.mmdl",
package = "Certara.RsNLME"),
directoryToExtract = tempdir())
} # }