Create a textual model object
textualmodel.RdUse to create an empty model object and optionally supply location of .mdl file or PML code as a character string to initialize model with PML statements.
Arguments
- modelName
Model name to create subdirectory for model output in current working directory.
- workingDir
Working directory to run the model. Current working directory will be used if
workingDirnot specified.- data
Input dataset
- mdl
File path specifying location of .mdl file. Cannot be used together with
pml.- pml
PML code as a character string. Cannot be used together with
mdl.