Remove NLME License
remove_NLMELicense.RdThis function attempts to remove an NLME license using the specified installation directory and licensing tool.
Usage
remove_NLMELicense(InstallDir = Sys.getenv("INSTALLDIR"))Details
The function checks for the presence of the necessary
appsettings.json file in the specified directory or the CAD config file
specified by the CAD_CONFIG_FILE environment variable, runs the licensing
tool to log out the user, and attempts to remove the NLME license.
Examples
if (FALSE) { # \dontrun{
INSTALLDIR <- Sys.getenv("INSTALLDIR")
if (INSTALLDIR == "") INSTALLDIR <- "C:/Program Files/Certara/NLME_Engine"
if (FALSE) { # to prevent unintended logout
result <- remove_NLMELicense(INSTALLDIR)
}
} # }